@@ -97,6 +97,18 @@ LINK_CONNECTOR_CONFIG_DEFAULT = {
     }
 }
 
+# Check if OS is Linux or Windows (#47):
+OS_TYPE_WINDOWS = False
+try:
+    from platform import system
+    if 'Windows' in system():
+        OS_TYPE_WINDOWS = True
+        log.debug("OS Type: Windows")
+    else:
+        log.debug("OS Type: Linux")
+except:  # noqa: E722
+    log.warning("Could not determine OS-Type (Linux/Windows). Using default: 'Linux'.")
+
 
 class PyOTRSError(Exception):
     def __init__(self, message):
@@ -838,12 +850,15 @@ class SessionStore(object):
             full_file_path (str): full path to file on disc
 
         Returns:
-            **bool**: **True** if valid and correct, otherwise **False**...
+            **bool**: **True** if valid and correct (or running on Windows), otherwise **False**...
 
         """
         if not os.path.isfile(full_file_path):
             raise IOError("Does not exist or not a file: {0}".format(full_file_path))
 
+        if OS_TYPE_WINDOWS:  # We have to do this, as os.getuid() is not defined if run on Windows
+            return True
+
         file_lstat = os.lstat(full_file_path)
         if not file_lstat.st_uid == os.getuid():
             return False
@@ -922,7 +937,14 @@ class Client(object):
             self.session_timeout = session_timeout
 
         if not session_id_file:
-            self.session_id_store = SessionStore(file_path="/tmp/.pyotrs_session_id",
+            if OS_TYPE_WINDOWS:
+                # No '/tmp/...' available on Windows OS, so using in Windows Temp folder instead
+                p = os.path.expanduser('~\\AppData\\Local\\Temp\\.pyotrs_session_id')
+                SESSION_ID_PATH = p
+            else:
+                SESSION_ID_PATH = "/tmp/.pyotrs_session_id"  # Default for Linux
+
+            self.session_id_store = SessionStore(file_path=SESSION_ID_PATH,
                                                  session_timeout=self.session_timeout,
                                                  is_legacy=use_legacy_sessions)
         else:
